![PyPI](https://img.shields.io/pypi/v/rs_metrics?color=%2300ccff)

This package implements metrics common in recommendation systems.

## Installation

```bash
pip install rs_metrics
```

## Documentation

Docs are available [here](https://darel13712.github.io/rs_metrics/)